<?php

namespace FiloBlu\GuestWishlist\Cron;

/**
 * @property Magento\Framework\App\ResourceConnection _connection
 */
class CleanOldGuestWishlist {

    protected $_helper;
    protected $_loggerCron;
    private $_connection;

    /**
     * CleanOldGuestWishlist constructor.
     * @param \FiloBlu\GuestWishlist\Helper\Data $helper
     * @param \FiloBlu\GuestWishlist\Model\Logger\LoggerCron $loggerCron
     * @param \Magento\Framework\App\ResourceConnection $connection
     */
    public function __construct(
        \FiloBlu\GuestWishlist\Helper\Data $helper,
        \FiloBlu\GuestWishlist\Model\Logger\LoggerCron $loggerCron,
        \Magento\Framework\App\ResourceConnection $connection
    ) {
        $this->_connection = $connection;
        $this->_helper = $helper;
        $this->_loggerCron = $loggerCron;
    }

    public function execute() {

        if ($this->_helper->isCronEnabled()) {
            try {

                $resource = $this->_connection->getConnection();

                $this->_loggerCron->info(" #### START CRON CleanOldWishlist #### ");

                $tableWishlist = $this->_connection->getTableName('wishlist');

                // Current date and time
                $datetime = date("Y-m-d H:i:s");

                // Convert datetime to Unix timestamp
                $timestamp = strtotime($datetime);

                // Subtract time from datetime
                $time = $timestamp - ($this->_helper->getCookielifetime());

                // Date and time after subtraction
                $datetime = date("Y-m-d H:i:s", $time);

                $resource->delete( $tableWishlist, ['customer_id' => new \Zend_Db_Expr('is null'),'updated_at <= ?'=>$datetime] );

                $this->_loggerCron->info(" #### Clean Wishlist Before -> " . $datetime . " #### ");

                $this->_loggerCron->info(" #### END CRON CleanOldWishlist #### ");
                
            } catch (\Exception $e) {
                $this->_loggerCron->info(" #### ERROR -> " . $e->getMessage() . " #### ");
            }
        }
    }

}
